@@ -133,7 +133,7 @@ check_print_step = function(print_step) {
 }
 
 # x variable
-x_variable = function(dt, y, x, var_skip=NULL) {
+x_variable = function(dt, y, x, var_skip=NULL, method = NULL) {
   x_all = setdiff(names(dt), c(y, var_skip))
 
   if (is.null(x)) x = x_all
@@ -143,6 +143,11 @@ x_variable = function(dt, y, x, var_skip=NULL) {
     x = intersect(x, x_all)
   }
 
+  if (any(method %in% c('freq', 'width'))) {
+    x_num = setdiff(names(dt)[sapply(dt, is.numeric)], c(y, var_skip))
+    x = intersect(x, x_num)
+  }
+
   return(x)
 }
 
